import React from 'react';
import { Hook } from 'tapable';
import { Plugin } from '../plugins';
interface UI {
    Alert: any;
    Button: any;
    Form: any;
    Loading: any;
    Modal: any;
    Page: any;
    Table: any;
    Layout: any;
    Checkbox: any;
}
export declare type UIType = UI | null;
interface FilterMeta {
    filter: string;
}
interface RefDataMeta {
    ref: string;
    refData?: {
        [x: string]: {
            [x: string]: any;
        }[];
    };
}
interface DataMeta {
    data: {
        [x: string]: any;
    }[];
    pageSize?: number;
}
interface FetchMeta {
    url: string;
    method?: string;
    alias?: {
        [x: string]: string;
    };
}
export interface ActionMeta {
    label: string;
    modal?: string;
    link?: string;
    url?: string;
    params?: {
        [x: string]: any;
    };
    method?: string;
}
interface LayoutMeta {
    direction: string;
    width?: number;
    columnsCount?: number;
}
export declare type Meta = FilterMeta | FetchMeta | ActionMeta | LayoutMeta | DataMeta | RefDataMeta;
export interface TableAction {
    key: string;
    meta: ActionMeta;
}
export interface PageSectionItem {
    key: string;
    label: string;
    id?: boolean;
    type?: string;
    meta?: FetchMeta;
    actions?: TableAction[];
    editable?: boolean;
    data?: any[] | string;
}
export interface PageSection {
    type: string;
    key: string;
    alias?: string;
    disabled?: boolean;
    items?: (PageSectionItem | PageSection)[];
    meta?: Meta;
}
export interface MenuItem {
    key: string;
    label: string;
    pageJSON?: PageSection[];
    index?: boolean;
    params?: string[];
}
export interface MenuGroup {
    label: string;
    subs: MenuItem[];
}
export declare function isMenuGroup(item: MenuItem | MenuGroup): item is MenuGroup;
export interface ConfigType {
    appKey: string;
    appTitle: string;
    menus: (MenuGroup | MenuItem)[];
    pageAPI?: string;
    loginUrl?: string;
}
export interface AppHooks {
    afterMenusFetched: Hook;
    afterPageLoaded: Hook;
    afterPageUnloaded: Hook;
    afterComponentLoaded: Hook;
    afterComponentUnloaded: Hook;
    beforeFormSelectFetched: Hook;
    afterFormSelectFetched: Hook;
    beforeTableDataSourceFetched: Hook;
    afterTableDataSourceFetched: Hook;
    beforeFormItemsFinalization: Hook;
    beforeTableColumnFinalization: Hook;
    beforeButtonClick: Hook;
    beforeFormSubmit: Hook;
    beforeCheckboxChange: Hook;
}
interface AppType {
    ui: UIType;
    config: ConfigType;
    hooks: AppHooks;
}
export declare const App: React.Context<AppType>;
interface IProps {
    ui: UIType;
    config: ConfigType;
    plugins: Plugin[];
    debugHooks?: string[];
    children: React.ReactNode;
}
export declare function AppProvider(props: IProps): JSX.Element;
export {};
